@@ -1,16 +1,17 @@
 """errors and exceptions."""
 
+from __future__ import annotations
+
 from flask.wrappers import Response
 from werkzeug import exceptions
 
-from .typing import Optional
 from .wrappers import Limit
 
 
 class RateLimitExceeded(exceptions.TooManyRequests):
     """Exception raised when a rate limit is hit."""
 
-    def __init__(self, limit: Limit, response: Optional[Response]) -> None:
+    def __init__(self, limit: Limit, response: Response | None = None) -> None:
         """
         :param limit: The actual rate limit that was hit.
          Used to construct the default response message
